@@ -2,7 +2,7 @@ import responses
 import pytest
 
 import rsapi
-import rsapi.osrs
+import rsapi.osrs as osrs
 
 
 TEST_DATA = """\
@@ -84,10 +84,12 @@ TEST_DATA = """\
 -1,-1
 -1,-1
 -1,-1
+-1,-1
+-1,-1
 -1,-1"""
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def mock_hiscores():
     with responses.RequestsMock() as rsps:
         mock_url = f"{rsapi.API_URL}/{rsapi.osrs.HISCORES_PATH}"
@@ -96,7 +98,25 @@ def mock_hiscores():
 
 
 def test_hiscores(mock_hiscores):
-    scores = rsapi.osrs.hiscores("jakop")
+    scores = osrs.hiscores("jakop")
     assert scores["Overall"]["level"] == 828, "Overall score mismatch"
     assert scores["Overall"]["exp"] == 11351102, "Overall exp mismatch"
     assert scores["Overall"]["rank"] == 1498141, "Overall rank mismatch"
+
+
+def test_player_not_found():
+    with responses.RequestsMock() as rsps:
+        mock_url = f"{rsapi.API_URL}/{rsapi.osrs.HISCORES_PATH}"
+        rsps.add(responses.GET, mock_url, body="NOT FOOND", status=404)
+        with pytest.raises(rsapi.PlayerNotFound):
+            osrs.hiscores("jakop")
+
+
+def test_items():
+    items = osrs.items("Ana in a barrel")
+    assert len(items) == 1, "Expected to find Ana"
+
+
+def test_item_not_found():
+    with pytest.raises(rsapi.ItemError):
+        osrs.items("Ana not in a barrel")
